==> libzen_0.4.27.orig.tar.gz: ZenLib/Source/ZenLib/Conf.cpp <==
// ZenLib::ZenTypes - To be independant of platform & compiler
// Copyright (C) 2002-2011 MediaArea.net SARL, Info@MediaArea.net
//
// This software is provided 'as-is', without any express or implied
// warranty.  In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would be
//    appreciated but is not required.
// 2. Altered source versions must be plainly marked as such, and must not be
//    misrepresented as being the original software.
// 3. This notice may not be removed or altered from any source distribution.
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

//---------------------------------------------------------------------------
#include "ZenLib/PreComp.h"
#ifdef __BORLANDC__
    #pragma hdrstop
#endif
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
#include "ZenLib/Conf_Internal.h"
//---------------------------------------------------------------------------

namespace ZenLib
{

//***************************************************************************
// Platform differences
//***************************************************************************

//End of line
#ifdef WINDOWS
    const Char* EOL=_T("\r\n");
    const Char  PathSeparator=_T('\\');
#endif
#ifdef UNIX
    const Char* EOL=_T("\n");
    const Char  PathSeparator=_T('/');
#endif
#if defined (MACOS) || defined (MACOSX)
    const Char* EOL=_T("\r");
    const Char  PathSeparator=_T('/');
#endif

//***************************************************************************
//
//***************************************************************************

} //namespace

==> libzen_0.4.28.orig.tar.gz: ZenLib/Source/ZenLib/Conf.cpp <==
// ZenLib::ZenTypes - To be independant of platform & compiler
// Copyright (C) 2002-2011 MediaArea.net SARL, Info@MediaArea.net
//
// This software is provided 'as-is', without any express or implied
// warranty.  In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would be
//    appreciated but is not required.
// 2. Altered source versions must be plainly marked as such, and must not be
//    misrepresented as being the original software.
// 3. This notice may not be removed or altered from any source distribution.
//
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

//---------------------------------------------------------------------------
#include "ZenLib/PreComp.h"
#ifdef __BORLANDC__
    #pragma hdrstop
#endif
//---------------------------------------------------------------------------

//---------------------------------------------------------------------------
#include "ZenLib/Conf_Internal.h"
//---------------------------------------------------------------------------

namespace ZenLib
{

//***************************************************************************
// Platform differences
//***************************************************************************

//End of line
#ifdef WINDOWS
    const Char* EOL=__T("\r\n");
    const Char  PathSeparator=__T('\\');
#endif
#ifdef UNIX
    const Char* EOL=__T("\n");
    const Char  PathSeparator=__T('/');
#endif
#if defined (MACOS) || defined (MACOSX)
    const Char* EOL=__T("\r");
    const Char  PathSeparator=__T('/');
#endif

//***************************************************************************
//
//***************************************************************************

} //namespace
